@@ -17,7 +17,7 @@
  autora (https://github.com/MrYsLab/pymata-aio/tree/master/FirmataPlus)
 '''
 
-_pytechbrain_version_ = '0.7.3'
+_pytechbrain_version_ = '0.7.6'
 
 # definicje nut dla funkcji nuta
 C0=16
@@ -143,18 +143,27 @@ except:
     print('------------[ ERROR ]----------------------------------------------')
 
 from time import sleep
-from sys import platform, implementation, version
+from sys import platform, implementation, version, exit
 # import serial
 import serial.tools.list_ports
 
 python_version = (implementation.version.major, implementation.version.minor, implementation.version.micro)
 python_detail = f"{python_version}_{implementation.hexversion}"
 python_string = version.split("\n")[0]
+if python_version < (3,6,0):
+    print(f"Zbyt stara wersja Python -> {python_string}")
+    print("Moduł działa tylko dla wersji minimum 3.6.0")
+    exit(3)
+
 print(f'OK - załadowałem moduł PyTechBrain... [ {_pytechbrain_version_} ] on {python_string}')
 print("Sprawdzam istniejące porty i urządzenia:")
+
 adapters = list(serial.tools.list_ports.comports())
 for val in adapters:
-    print(f"Element: {val.device} / {val.product} / {val.usb_description()}")
+    if sys.platform in ("linux", "darwin"):
+        print(f"Element: {val.device} / {val.product} / {val.usb_description()}")
+    if sys.platform.startwith("win"):
+        print(f"Element: {val.description} / {val.manufacturer} / {val.usb_info()}")
 print("-----------------------------------------------")
 print("""Aby aktywować układ, wpisz:
 uklad = PyTechBrain()
@@ -174,29 +183,16 @@ class PyTechBrain:
 
     def __init__(self, szukaj='auto'):
 
-        def arduino_port_old():
-            adapters = list(serial.tools.list_ports.comports())
-            for val in adapters:
-                if platform in ("linux", "darwin") and val[1] == 'ABIX_PyTechBrain':
-                    print(f"Found on {val}")
-                    return val
-                elif platform == "win" and val[1] == 'USB':
-                    print(f"Found on {val}")
-                    return val
-            else:
-                print("Found no adapter....")
-                print(adapters)
-                return False
 
-        def arduino_port_38():
+        def arduino_port_pyserial_35():
             adapters = list(serial.tools.list_ports.comports())
             for val in adapters:
                 if platform in ("linux", "darwin") and val.product == 'ABIX_PyTechBrain':
                     print(f"Found on {val.device}")
                     return val.device
-                elif platform == "win" and val[1] == 'USB':
-                    print(f"Found on {val.device}")
-                    return val.device
+                elif platform == "win" and (val.manufacturer == 'FTDI' or val.description.startswith("USB Serial")):
+                    print(f"Found on {val.name}")
+                    return val.name
             else:
                 print("Found no adapter....")
                 return False
@@ -205,10 +201,7 @@ class PyTechBrain:
         if szukaj == 'auto':
             print('Próba automatycznej detekcji portu ...')
             try:
-                if python_version >= (3, 8, 10):
-                    port = arduino_port_38()
-                else:
-                    port = arduino_port_old()
+                port = arduino_port_pyserial_35()
             except:
                 print('Coś nie tak z poszukiwaniem plytki - może nie podłączona?')
                 exit()
